@@ -7,7 +7,7 @@
 TEXTDOMAINDIR=/usr/share/locale
 TEXTDOMAIN=set_time-and_date
 
-DIALOG="`which yad` --width 400 --center --undecorated"
+DIALOG="`which yad` --width 550 --center --undecorated"
 TITLE="--always-print-result --dialog-sep --title="
 TEXT="--text="
 ENTRY="--entry "
@@ -24,6 +24,8 @@ SETTIME_TEXT=$"Set Current Time"
 SETDATE_TEXT=$"Set Current Date"
 SETTZ_TEXT=$"Choose Time Zone (using cursor and enter keys)"
 SETAUTO_TEXT=$"Use Internet Time server to set automaticaly time/date"
+SETLOCAL_TEXT=$"Set system clock time scale to LOCAL"
+SETUTC_TEXT=$"Set system clock time scale to UTC"
 SETHOUR_TEXT=$"Move the slider to the correct Hour"
 SETMINUTE_TEXT=$"Move the slider to the correct Minute"
 SETTIMEZONE_TEXT=$"Select Time Zone"
@@ -42,7 +44,7 @@ MONTH="`date +%m`"
 YEAR="`date +%Y`"
 MINUTE="`date +%M`"
 HOUR="`date +%H`"
-SETCHOICE=`$DIALOG --no-buttons --center --height 300 $TITLE"$TITLETEXT" $MENU $TEXT" $TITLETEXT\n $DATE_TEXT\n $(date)\n\n" SETTIME " $SETTIME_TEXT" SETDATE " $SETDATE_TEXT"  SETTZ " $SETTZ_TEXT"  SETAUTO " $SETAUTO_TEXT" Exit " $EXIT_TEXT"`
+SETCHOICE=`$DIALOG --no-buttons --center --height 300 $TITLE"$TITLETEXT" $MENU $TEXT" $TITLETEXT\n $DATE_TEXT\n $(date)\n\n" SETTIME " $SETTIME_TEXT" SETDATE " $SETDATE_TEXT"  SETTZ " $SETTZ_TEXT"  SETAUTO " $SETAUTO_TEXT" SETLOCAL " $SETLOCAL_TEXT" SETUTC " $SETUTC_TEXT" Exit " $EXIT_TEXT"`
 SETCHOICE=`echo $SETCHOICE | cut -d "|" -f 1`
  
 if [ "$SETCHOICE" = "SETTIME" ]; then
@@ -70,7 +72,9 @@ if [ "$SETCHOICE" = "SETTIME" ]; then
 fi
  
 if [ "$SETCHOICE" = "SETDATE" ]; then
-    var=`$DIALOG --form --separator="" --date-format="%Y%m%d" --field="$DATE_TEXT":DT`
+    #var=`$DIALOG --form --separator="" --date-format="%Y%m%d" --field="$DATE_TEXT":DT`
+    var=$(yad --calendar --undecorated --center --date-format="%Y%m%d")
+
 SETYEAR=$(echo ${var:0:4})
 SETMONTH=$(echo ${var:4:2})
 SETDAY=$(echo ${var:6:2})
@@ -87,8 +91,18 @@ fi
  
 if [ "$SETCHOICE" = "SETTZ" ]; then
 sudo roxterm --hide-menubar -z 0.75 -T " $SETTIMEZONE_TEXT" -e /bin/bash -c "dpkg-reconfigure tzdata"
- 
+
 fi
+
+if [ "$SETCHOICE" = "SETLOCAL" ]; then
+sudo hwclock --systohc --localtime
+fi
+
+if [ "$SETCHOICE" = "SETUTC" ]; then
+sudo hwclock --systohc --utc
+fi
+
+
 done
  
 exit 0
